@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -166,6 +166,7 @@ ATTRIBUTES = dict(
     autoresponse_request_text=GetterSetter(str),
     bounces_address=GetterSetter(None),
     bounce_info_stale_after=GetterSetter(as_timedelta),
+    bounce_notify_owner_on_bounce_increment=GetterSetter(as_boolean),
     bounce_notify_owner_on_disable=GetterSetter(as_boolean),
     bounce_notify_owner_on_removal=GetterSetter(as_boolean),
     bounce_score_threshold=GetterSetter(integer_ge_zero_validator),
@@ -233,6 +234,7 @@ ATTRIBUTES = dict(
     request_address=GetterSetter(None),
     require_explicit_destination=GetterSetter(as_boolean),
     respond_to_post_requests=GetterSetter(as_boolean),
+    send_goodbye_message=GetterSetter(as_boolean),
     send_welcome_message=GetterSetter(as_boolean),
     subject_prefix=GetterSetter(str),
     subscription_policy=GetterSetter(enum_validator(SubscriptionPolicy)),
