@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -48,6 +48,7 @@ RESOURCE = dict(
     allow_list_posts=False,
     anonymous_list=True,
     archive_policy='never',
+    archive_rendering_mode='text',
     autorespond_owner='respond_and_discard',
     autorespond_postings='respond_and_continue',
     autorespond_requests='respond_and_discard',
@@ -56,6 +57,7 @@ RESOURCE = dict(
     autoresponse_postings_text='the mailing list',
     autoresponse_request_text='the robot',
     bounce_info_stale_after='7d',
+    bounce_notify_owner_on_bounce_increment=False,
     bounce_notify_owner_on_disable=False,
     bounce_notify_owner_on_removal=True,
     bounce_score_threshold=5,
@@ -78,6 +80,7 @@ RESOURCE = dict(
     dmarc_mitigate_unconditionally=False,
     dmarc_moderation_notice='Some moderation notice',
     dmarc_wrapped_message_text='some message text',
+    emergency=False,
     filter_action='discard',
     filter_extensions=['.exe'],
     filter_content=True,
@@ -110,6 +113,7 @@ RESOURCE = dict(
     reply_to_address='bee@example.com',
     require_explicit_destination=True,
     member_roster_visibility='public',
+    send_goodbye_message=False,
     send_welcome_message=False,
     subject_prefix='[ant]',
     subscription_policy='confirm_then_moderate',
@@ -516,6 +520,28 @@ class TestConfiguration(unittest.TestCase):
                 'PATCH')
             self.assertEqual(self._mlist.info, '')
 
+    def test_patch_send_welcome_message(self):
+        with transaction():
+            self._mlist.send_welcome_message = False
+        resource, response = call_api(
+            'http://localhost:9001/3.0/lists/ant.example.com/config'
+            '/send_welcome_message',
+            dict(send_welcome_message=True),
+            'PATCH')
+        self.assertEqual(response.status_code, 204)
+        self.assertTrue(self._mlist.send_welcome_message)
+
+    def test_patch_send_goodbye_message(self):
+        with transaction():
+            self._mlist.send_goodbye_message = False
+        resource, response = call_api(
+            'http://localhost:9001/3.0/lists/ant.example.com/config'
+            '/send_goodbye_message',
+            dict(send_goodbye_message=True),
+            'PATCH')
+        self.assertEqual(response.status_code, 204)
+        self.assertTrue(self._mlist.send_goodbye_message)
+
     def test_delete_top_level_listconf(self):
         with self.assertRaises(HTTPError) as cm:
             call_api('http://localhost:9001/3.0/lists/ant.example.com/config',
