@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -21,8 +21,10 @@ import os
 import re
 import unittest
 
+from email import message_from_binary_file, message_from_bytes
 from email.iterators import _structure as structure
 from email.mime.text import MIMEText
+from importlib_resources import open_binary
 from io import StringIO
 from mailman.app.lifecycle import create_list
 from mailman.config import config
@@ -67,6 +69,13 @@ class TestDigest(unittest.TestCase):
         for item in items:
             self.assertEqual(item.msg['subject'],
                              'Test Digest, Vol 1, Issue 1')
+        return items
+
+    def _get_plain_body(self, items):
+        # Need to run after _check_virgin_queue which gets the items.
+        for item in items:
+            if item.msg.get_content_type() == 'text/plain':
+                return item.msg.get_payload(decode=True)
 
     def test_simple_message(self):
         # Subscribe some users receiving digests.
@@ -101,6 +110,95 @@ class TestDigest(unittest.TestCase):
         self.assertEqual(len(self._shuntq.files), 0, error_log.read())
         self._check_virgin_queue()
 
+    def test_utf7_message_with_inline_ascii_sig(self):
+        # The test message is bigger than 1K.  Set the threshold bigger to
+        # avoid double processing in make_digest_messages.
+        self._mlist.digest_size_threshold = 5
+        # Subscribe some users receiving digests.
+        anne = subscribe(self._mlist, 'Anne')
+        anne.preferences.delivery_mode = DeliveryMode.mime_digests
+        bart = subscribe(self._mlist, 'Bart')
+        bart.preferences.delivery_mode = DeliveryMode.plaintext_digests
+        with open_binary('mailman.runners.tests.data',
+                         'ascii_in_utf7.eml') as fp:
+            msg = message_from_binary_file(fp, Message)
+        # Use any error logs as the error message if the test fails.
+        error_log = LogFileMark('mailman.error')
+        make_digest_messages(self._mlist, msg)
+        # The runner will send the file to the shunt queue on exception.
+        self.assertEqual(len(self._shuntq.files), 0, error_log.read())
+        self._check_virgin_queue()
+
+    def test_non_ascii_in_ascii_part(self):
+        # Subscribe some users receiving digests.
+        anne = subscribe(self._mlist, 'Anne')
+        anne.preferences.delivery_mode = DeliveryMode.mime_digests
+        bart = subscribe(self._mlist, 'Bart')
+        bart.preferences.delivery_mode = DeliveryMode.plaintext_digests
+        msg = message_from_bytes(b"""\
+From: anne@example.org
+To: test@example.com
+Subject: Non-ascii in ascii message
+MIME-Version: 1.0
+Content-Type: multipart/mixed; boundary="abcxyz"
+
+--abcxyz
+Content-Type: text/plain; charset=us-ascii
+Content-Transfer-Encoding: 8bit
+
+Don\xe2\x80\x99t try this at home.
+--abcxyz--
+""", Message)
+        # Use any error logs as the error message if the test fails.
+        error_log = LogFileMark('mailman.error')
+        make_digest_messages(self._mlist, msg)
+        # The runner will send the file to the shunt queue on exception.
+        self.assertEqual(len(self._shuntq.files), 0, error_log.read())
+        items = self._check_virgin_queue()
+        self.assertEqual(self._get_plain_body(items), b"""\
+Send Test mailing list submissions to
+\ttest@example.com
+
+To subscribe or unsubscribe via email, send a message with subject or
+body 'help' to
+\ttest-request@example.com
+
+You can reach the person managing the list at
+\ttest-owner@example.com
+
+When replying, please edit your Subject line so it is more specific
+than "Re: Contents of Test digest..."
+
+Today\'s Topics:
+
+   1. Non-ascii in ascii message (anne@example.org)
+
+
+----------------------------------------------------------------------
+
+Message: 1
+From: anne@example.org
+Subject: Non-ascii in ascii message
+To: test@example.com
+Content-Type: multipart/mixed; boundary="abcxyz"
+
+Don\xef\xbf\xbd\xef\xbf\xbd\xef\xbf\xbdt try this at home.
+
+------------------------------
+
+Subject: Digest Footer
+
+_______________________________________________
+Test mailing list -- test@example.com
+To unsubscribe send an email to test-leave@example.com
+
+
+------------------------------
+
+End of Test Digest, Vol 1, Issue 1
+**********************************
+""")
+
     def test_mime_digest_format(self):
         # Make sure that the format of the MIME digest is as expected.
         self._mlist.digest_size_threshold = 0.6
