@@ -86,7 +86,10 @@ def make_testable_runner(runner_class, name=None, predicate=None):
             """Stop when the queue is empty."""
             super()._do_periodic()
             if predicate is None:
-                self._stop = (len(self.switchboard.files) == 0)
+                if self.switchboard is None:
+                    self._stop = True
+                else:
+                    self._stop = (len(self.switchboard.files) == 0)
             else:
                 self._stop = predicate(self)
 
@@ -291,7 +294,7 @@ def call_api(url, data=None, method=None, username=None, password=None,
     :type username: str
     :param password: The HTTP Basic Auth password.  None means use the value
         from the configuration.
-    :type username: str
+    :type password: str
     :param headers: List of additional headers to be included with the request.
     :type headers: A dictionary of {'Header': 'Value'}
     :param json: JSON body for the request.
